@@ -1,4 +1,4 @@
-// Copyright 2016 Dmitry Tantsur <divius.inside@gmail.com>
+// Copyright 2017 Dmitry Tantsur <divius.inside@gmail.com>
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -20,3 +20,6 @@
 
 pub mod base;
 pub mod identity;
+
+pub use self::base::{AuthError, AuthMethod, NoAuth};
+pub use self::identity::Identity;
