@@ -1,4 +1,4 @@
-// Copyright 2016 Dmitry Tantsur <divius.inside@gmail.com>
+// Copyright 2017 Dmitry Tantsur <divius.inside@gmail.com>
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -20,9 +20,15 @@
 #![crate_name = "openstack"]
 #![crate_type = "lib"]
 
+#[macro_use]
 extern crate hyper;
+extern crate hyper_openssl;
 #[macro_use]
 extern crate log;
+#[macro_use]
+extern crate mime;
 extern crate rustc_serialize;
+extern crate time;
 
 pub mod auth;
+pub mod utils;
